@@ -1,5 +1,5 @@
 test_that("externalptr", {
-  expect_snapshot({
+  expect_pipe_snapshot({
     dt <- data.table::data.table(a = 1)
     class(dt) <- "data.frame"
     construct(dt)
