@@ -1,5 +1,5 @@
 test_that("matrix", {
-  expect_snapshot({
+  expect_pipe_snapshot({
     construct(WorldPhones)
     construct(matrix(1:9, 3))
     construct(matrix(1:9, 1))
