@@ -1,7 +1,7 @@
 test_that("quosure", {
-  expect_snapshot({
+  expect_pipe_snapshot({
     construct(rlang::new_quosure(quote(x), .GlobalEnv))
     construct(rlang::new_quosure(quote(x), .GlobalEnv), opts_quosure("next"))
     construct(rlang::new_quosure(quote(x), .GlobalEnv), opts_quosure("language"))
-    })
+  })
 })
